/*
 *
 *  Copyright (c) 2012 Sven Langkamp <sven.langkamp@gmail.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifndef KIS_DLG_BLACKLIST_CLEANUP_H
#define KIS_DLG_BLACKLIST_CLEANUP_H

#include <KoDialog.h>
#include <ui_wdgdlgblacklistcleanup.h>

class KisDlgBlacklistCleanup : public KoDialog, public Ui_WdgDisplayBlacklist
{

public:
    KisDlgBlacklistCleanup();
    void accept() override;
};

#endif // KIS_DLG_BLACKLIST_CLEANUP_H
